pub unsafe extern "C" fn JSObjectSetPrivate(
    object: JSObjectRef,
    data: *mut c_void
) -> bool
Sets a pointer to private data on an object.

  • object: The JSObject whose private data you want to set.
  • data: A void* to set as the object’s private data.

Returns true if object can store private data, otherwise false.

The default object class does not allocate storage for private data. Only objects created with a non-NULL JSClass can store private data.