pub unsafe extern "C" fn JSPropertyNameArrayGetCount(
    array: JSPropertyNameArrayRef
) -> usize
Gets a count of the number of items in a JavaScript property name array.

  • array: The array from which to retrieve the count.

Return an integer count of the number of names in array.

See also: