Function javascriptcore_sys::JSStringGetLength
source · pub unsafe extern "C" fn JSStringGetLength(
string: JSStringRef
) -> usizeExpand description
Returns the number of Unicode characters in a JavaScript string.
string: TheJSStringwhose length (in Unicode characters) you want to know.
Returns the number of Unicode characters stored in string.