pub unsafe extern "C" fn JSValueMakeBoolean(
    ctx: JSContextRef,
    boolean: bool
) -> JSValueRef
Creates a JavaScript value of the boolean type.

  • ctx: The execution context to use.
  • boolean: The bool to assign to the newly created JSValue.

Returns a JSValue of the boolean type, representing the value of boolean.