Function javascriptcore_sys::JSValueUnprotect
source · pub unsafe extern "C" fn JSValueUnprotect(
ctx: JSContextRef,
value: JSValueRef
)Expand description
Unprotects a JavaScript value from garbage collection.
A value may be protected multiple times and must be unprotected an equal number of times before becoming eligible for garbage collection.
ctx: The execution context to use.value: TheJSValueto unprotect.